@@ -89,23 +89,28 @@ class Http(object):
         }
 
     def __verify_ssl(self):
-        if not Configuration.use_unsafe_ssl:
-            try:
-                from M2Crypto import SSL
-            except ImportError, e:
-                print "Cannot load M2Crypto.  Please refer to Braintree documentation."
-                print """
-If you are in an environment where you absolutely cannot load M2Crypto
+        if Configuration.use_unsafe_ssl: return
+
+        try:
+            import pycurl
+        except ImportError, e:
+            print "Cannot load PycURL.  Please refer to Braintree documentation."
+            print """
+If you are in an environment where you absolutely cannot load PycURL
 (such as Google App Engine), you can turn off SSL Verification by setting:
 
     Configuration.use_unsafe_ssl = True
 
 This is highly discouraged, however, since it leaves you susceptible to
 man-in-the-middle attacks."""
-                raise e
+            raise e
 
-            ctx = SSL.Context()
-            ctx.set_verify(SSL.verify_peer | SSL.verify_fail_if_no_peer_cert, depth=9)
-            ctx.load_verify_locations(self.environment.ssl_certificate)
-            s = SSL.Connection(ctx)
-            s.connect((self.environment.server, self.environment.port))
+        curl = pycurl.Curl()
+        # see http://curl.haxx.se/libcurl/c/curl_easy_setopt.html for info on these options
+        curl.setopt(pycurl.CAINFO, self.environment.ssl_certificate)
+        curl.setopt(pycurl.SSL_VERIFYPEER, 1)
+        curl.setopt(pycurl.SSL_VERIFYHOST, 2)
+        curl.setopt(pycurl.NOBODY, 1)
+        curl.setopt(pycurl.NOSIGNAL, 1)
+        curl.setopt(pycurl.URL, self.environment.protocol + self.environment.server_and_port)
+        curl.perform()
